@@ -6,6 +6,9 @@
 # Change interpretation
 # JTT 26.4.2008
 
+# Parameter settings (default) for testing purposes
+#transform<-c("log2-linear")
+
 # Loads the normalized data
 file<-c("normalized.tsv")
 dat<-read.table(file, header=T, sep="\t", row.names=1)
@@ -43,7 +46,7 @@ if(transform=="linear-ln") {
 	if(any(dat2<0)) {
 		stop("Negative values in the data! Can't log-transform.")
 	}
-	dat2<-ln(dat2)
+	dat2<-log(dat2)
 }
 
 # Add the annotations and flags back into the data table
