@@ -5,6 +5,9 @@
 
 # JTT, 14.1.2008
 
+# Parameter settings (default) for testing purposes
+#percentage.to.filter.out<-c(0.5)
+
 # Renaming variables
 percentage<-percentage.to.filter.out
 
@@ -31,7 +34,7 @@ colno<-ncol(dat2)
 g.mean <- rowSums(dat2)/colno
 g.sd <- rowSds(dat2)
 g.cv <- g.sd / g.mean
-sel<-(g.cv>quantile(g.cv,percentage))
+sel<-(g.cv>quantile(g.cv,percentage,na.rm=TRUE))
 set<-dat[sel, ]
 
 # Saving the results
