@@ -1,6 +1,6 @@
 # ANALYSIS Statistics/NMDS (Non-metric multidimensional scaling. Creates a 2-dimensional representation of 
 # the arrays using Euclidean distances. Can be used for quality control.)
-# INPUT GENE_EXPRS normalized.tsv, GENERIC phenodata.tsv OUTPUT nmds.png
+# INPUT GENE_EXPRS normalized.tsv, GENERIC phenodata.tsv OUTPUT nmds.pdf
 # PARAMETER image.width INTEGER FROM 200 TO 3200 DEFAULT 600 (Width of the plotted network image)
 # PARAMETER image.height INTEGER FROM 200 TO 3200 DEFAULT 600 (Height of the plotted network image)
 
@@ -8,6 +8,10 @@
 # Non-metric multidimensional scaling
 # JTT 14.1.2008
 
+# Parameter settings (default) for testing purposes
+#image.width<-c(600)
+#image.height<-c(600)
+
 # Renaming variables
 w<-image.width
 h<-image.height
@@ -33,7 +37,7 @@ dat2.dist<-dist(t(dat2))
 mds<-isoMDS(dat2.dist)
 
 # Plotting the image
-bitmap(file="nmds.png", width=w/72, height=h/72)
+pdf(file="nmds.pdf", width=w/72, height=h/72)
 plot(mds$points[,1], mds$points[,2], main="NMDS", pch=19, xlab="Dimension 1", ylab="Dimension 2", type="n")
 text(mds$points[,1], mds$points[,2], phenodata$description, cex=0.75, col=phenodata$group)
 dev.off()
