@@ -1,23 +1,23 @@
-# ANALYSIS "aCGH tools (beta testing)"/"Sample size calculations with an adapted BH method" ()
+# ANALYSIS "Statistics"/"Sample size calculations with an adapted BH method" (Perform sample size calculations using an adapted Benjamini-Hochberg method.)
 # INPUT GENE_EXPRS normalized.tsv, GENERIC phenodata.tsv
-# OUTPUT skewness.png, kurtosis.png, p-density.png, lambda.png, g.png, gamma.png, power.png, power.txt
+# OUTPUT skewness.pdf, kurtosis.pdf, p-density.pdf, lambda.pdf, g.pdf, gamma.pdf, power.pdf, power.txt
 # PARAMETER column METACOLUMN_SEL DEFAULT group (The phenodata column that divides the samples into exactly two groups.)
-# PARAMETER var.equal [TRUE, FALSE] DEFAULT FALSE ()
-# PARAMETER distribution [normal, student] DEFAULT normal ()
-# PARAMETER false.discovery.rate DECIMAL DEFAULT 0.1 ()
-# PARAMETER image.width INTEGER FROM 200 TO 3200 DEFAULT 600 (Width of the plotted network image)
-# PARAMETER image.height INTEGER FROM 200 TO 3200 DEFAULT 600 (Height of the plotted network image)
+# PARAMETER assume.equal.variances [yes, no] DEFAULT no (Whether to treat the variances of the two groups as equal.)
+# PARAMETER distribution [normal, student] DEFAULT normal (Whether to use the normal or the t distribution to calculate p values.)
+# PARAMETER false.discovery.rate DECIMAL DEFAULT 0.1 (False discovery rate.)
+# PARAMETER image.width INTEGER FROM 200 TO 6400 DEFAULT 2400 (Width of the plotted network image)
+# PARAMETER image.height INTEGER FROM 200 TO 6400 DEFAULT 2400 (Height of the plotted network image)
 
 # sample-size-with-bh.R
-# Ilari Scheinin <firstname.lastname@helsinki.fi>
-# 2010-03-20
+# Ilari Scheinin <firstname.lastname@gmail.com>
+# 2011-03-28
 
 dat <- read.table('normalized.tsv', header=TRUE, sep='\t', as.is=TRUE, row.names=1)
-phenodata <- read.table("phenodata.tsv", header=T, sep="\t")
+phenodata <- read.table("phenodata.tsv", header=TRUE, sep="\t")
 groups <- phenodata[,column]
 
 if(length(unique(groups[!is.na(groups)]))!=2)
-   stop("You need to have exactly two groups to run this analysis")
+   stop('CHIPSTER-NOTE: You need to have exactly two groups to run this analysis')
 
 example.data = list(x=dat[,grep('chip', colnames(dat))], y=groups, genenames=rownames(dat), geneid=1:nrow(dat), samplelabels=phenodata$description)
 
@@ -53,8 +53,14 @@ samples2<-as.matrix(example.data$x[,example.data$y==class.names[2] & !is.na(exam
 N1<-ncol(samples1)
 N2<-ncol(samples2)
 N<-1/(1/N1+1/N2)
-for(i in 1:n){ 
-  Sample.of.test.statistics[i]<-t.test(samples1[i,],samples2[i,],alternative="two.sided",mu=0,paired=FALSE,var.equal=(var.equal=='TRUE'))$statistic
+for(i in 1:n){
+  prob <- TRUE
+  try({
+    Sample.of.test.statistics[i]<-t.test(samples1[i,],samples2[i,],alternative="two.sided",mu=0,paired=FALSE,var.equal=(assume.equal.variances=='yes'))$statistic
+    prob <- FALSE
+  }, silent=TRUE)
+  if (prob)
+    Sample.of.test.statistics[i] <- 0
 }
 #
 #tests.of.normality<-matrix(0,nrow=n,ncol=2)
@@ -77,7 +83,7 @@ for (i in 1:1000) {
   normal.kurtosis[i,] <- c(kurtosis(rnd1), kurtosis(rnd2))
 }
 hist.norm <- function(x, norm = NULL, ...) {
-  u <- seq(min(x)-1, max(x)+1, length=401)
+  u <- seq(min(x, na.rm=TRUE)-1, max(x, na.rm=TRUE)+1, length=401)
   if (is.null(norm)) {
     d <- dnorm(u)
   } else {
@@ -118,12 +124,14 @@ hist.norm <- function(x, norm = NULL, ...) {
 #    main=as.character(class.names[j]))
 #  if(j==1){windows()}
 #}
-bitmap(file='skewness.png', width=image.width/72, height=image.height/72)
+# pdf(file='skewness.pdf', width=image.width/72, height=image.height/72)
+pdf(file='skewness.pdf')
 par(mfrow=c(1,2))
 hist.norm(sample.skewness[,1], normal.skewness[,1], main=as.character(class.names[1]), xlab='skewness')
 hist.norm(sample.skewness[,2], normal.skewness[,2], main=as.character(class.names[2]), xlab='skewness')
 dev.off()
-bitmap(file='kurtosis.png', width=image.width/72, height=image.height/72)
+# pdf(file='kurtosis.pdf', width=image.width/72, height=image.height/72)
+pdf(file='kurtosis.pdf')
 par(mfrow=c(1,2))
 hist.norm(sample.kurtosis[,1], normal.kurtosis[,1], main=as.character(class.names[1]), xlab='kurtosis')
 hist.norm(sample.kurtosis[,2], normal.kurtosis[,2], main=as.character(class.names[2]), xlab='kurtosis')
@@ -167,7 +175,8 @@ c<-1
 a.n<-n^((c-1)/2) #Smoothing parameter 
 x<-seq(1/resolution,1-1/resolution,1/resolution)
 density.estimate.of.p.values<-sapply(x,beta.kernel.density.at.x,Sample.of.p.values,a.n)
-bitmap(file='p-density.png', width=image.width/72, height=image.height/72)
+# pdf(file='p-density.pdf', width=image.width/72, height=image.height/72)
+pdf(file='p-density.pdf')
 plot(x,density.estimate.of.p.values,type='l',xlab="p-value",ylab="density",col=1,xlim=c(0,1),
 ylim=c(0,1.1*max(density.estimate.of.p.values)))
 rough.estimate.of.gamma<-beta.kernel.density.at.x(1-0.0001,Sample.of.p.values,a.n)
@@ -249,7 +258,8 @@ estimate.lambda.of.theta<-pmax(rep(0,length(theta.vector)),estimate.lambda.of.th
 Const<-sum(estimate.lambda.of.theta)*step.theta
 estimate.lambda.of.theta<-estimate.lambda.of.theta/Const
 #Plotting estimate.lambda.of.theta
-bitmap(file='lambda.png', width=image.width/72, height=image.height/72)
+# pdf(file='lambda.pdf', width=image.width/72, height=image.height/72)
+pdf(file='lambda.pdf')
 plot(theta.vector,estimate.lambda.of.theta,type='l',col=3,ylim=c(0,1.2*max(estimate.lambda.of.theta)),xlab=quote(theta),
 ylab=quote(lambda(theta)))
 title("Estimated density of effect sizes")
@@ -295,7 +305,8 @@ estimate.lambda.of.theta<-estimate.lambda.of.theta/Const
 G.n.hat.u<-sapply(as.matrix(u),G.hat.n.at.a.point,theta.vector,step.theta,estimate.lambda.of.theta,nu,N)
 H.n.u<-sapply(u,edf.at.a.point,Sample.of.p.values)
 G.n.tilde.u<-(H.n.u-initial.gamma*u)/(1-initial.gamma)
-bitmap(file='g.png', width=image.width/72, height=image.height/72)
+# pdf(file='g.pdf', width=image.width/72, height=image.height/72)
+pdf(file='g.pdf')
 plot(u,G.n.tilde.u,type='l',xlab=quote(u),ylab=quote(G(u)),lty=c(1,3),col=c(3,2),xlim=c(0,1),ylim=c(0,max(G.n.tilde.u)))
 lines(u,G.n.hat.u,col=2)
 legend(c(0.6,0.8),c(0.6,0.8),c("non-parametric","semi-parametric"),lty=c(1,3),col=c(3,2),bty="n")
@@ -327,7 +338,8 @@ distances<-sapply(as.matrix(gamma.vector),distance.between.estimates.of.G.n,u,st
 minimum.distance<-min(distances)
 gamma.hat<-gamma.vector[distances<=minimum.distance]
 #
-bitmap(file='gamma.png', width=image.width/72, height=image.height/72)
+# pdf(file='gamma.pdf', width=image.width/72, height=image.height/72)
+pdf(file='gamma.pdf')
 plot(gamma.vector,distances,type='l',xlab=quote(~~gamma),ylab=quote(D[n](gamma)),col=1,ylim=c(0,1))
 dev.off()
 #
@@ -368,14 +380,15 @@ for(Nprime in samplesize.N) {
     #lines(u,u/r)
     #title(paste("Power calculation for N'=",round(Nprime,digits=1),""))
 }
-bitmap(file='power.png', width=image.width/72, height=image.height/72)
+# pdf(file='power.pdf', width=image.width/72, height=image.height/72)
+pdf(file='power.pdf')
 plot(samplesize, power, type='b', main=paste('Power calculation for FDR = ', round(100*delta), '%', sep=''),
   xlim=c(0, 300), ylim=0:1, ylab='Average power',
   xlab=paste('Number of samples (', round(100*N1/(N1+N2)), '% ', class.names[1], ', ', round(100*N2/(N1+N2)), '% ', class.names[2], ')', sep=''))
 dev.off()
 #
-write.table(data.frame(samplesize, power), file="power.txt", quote=FALSE, col.names=FALSE, row.names=TRUE, sep='\t')
+write.table(data.frame(samplesize, power), file="power.txt", quote=FALSE, col.names=TRUE, row.names=FALSE, sep='\t')
 #
 ################################################################################################################################################
 
-# EOF
\ No newline at end of file
+# EOF
